pub enum OpenAIError {
Reqwest(Error),
ApiError(ApiError),
JSONDeserialize(Error, String),
FileSaveError(String),
FileReadError(String),
StreamError(Box<StreamError>),
Boxed(Box<dyn Error + Send + Sync + 'static>),
InvalidArgument(String),
}Available on crate feature
_api and non-target_family=wasm only.Variants
Reqwest(Error)
Underlying error from reqwest library after an API call was made
ApiError(ApiError)
OpenAI returns error object with details of API call failure
JSONDeserialize(Error, String)
Error when a response cannot be deserialized into a Rust type
FileSaveError(String)
Error on the client side when saving file to file system
FileReadError(String)
Error on the client side when reading file from file system
StreamError(Box<StreamError>)
Error on SSE streaming
Boxed(Box<dyn Error + Send + Sync + 'static>)
Available on crate feature
middleware only.Error from middlewares
InvalidArgument(String)
Error from client side validation or when builder fails to build request before making API call