pub struct SimpleRetryPolicy { /* private fields */ }Available on crate features
middleware and _api only.Expand description
Simple tower::retry::Policy for OpenAI compatible APIs.
SimpleRetryPolicy retries rate limits, server errors, and native connect
errors. It can be used directly with tower::ServiceBuilder::retry
around crate::middleware::ReqwestService or any compatible tower service
whose request type is crate::middleware::HttpRequestFactory.
The default policy allows three retry attempts.
Implementations
Sourceimpl SimpleRetryPolicy
impl SimpleRetryPolicy
Sourcepub fn new(max_retries: usize) -> Self
pub fn new(max_retries: usize) -> Self
Create a policy that allows at most max_retries retry attempts.
This value is the number of additional attempts after the initial request, not the total number of requests.
Sourcepub fn max_retries(&self) -> usize
pub fn max_retries(&self) -> usize
Number of retry attempts configured for this policy.