pub struct ReqwestService { /* private fields */ }Available on crate features
middleware and _api only.Expand description
Default tower-compatible service backed directly by reqwest::Client.
Users can layer retry, timeout, rate limiting, tracing, or any other tower
middleware around this service and then install the composed service with
Client::with_http_service(...).
Implementations