InviteRequestArgs

Struct InviteRequestArgs 

pub struct InviteRequestArgs { /* private fields */ }
Available on crate feature administration-types only.
Builder for InviteRequest.

Implementations

Source

impl InviteRequestArgs

pub fn email<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn role<VALUE: Into<OrganizationRole>>(&mut self, value: VALUE) -> &mut Self

pub fn projects<VALUE: Into<Vec<InviteProjectMembership>>>( &mut self, value: VALUE, ) -> &mut Self

An array of projects to which membership is granted at the same time the org invite is accepted. If omitted, the user will be invited to the default project for compatibility with legacy behavior.

pub fn build(&self) -> Result<InviteRequest, OpenAIError>

Builds a new InviteRequest.

Errors

If a required field has not been initialized.