ProjectCreateRequestArgs

Struct ProjectCreateRequestArgs 

pub struct ProjectCreateRequestArgs { /* private fields */ }
Available on crate feature administration-types only.
Builder for ProjectCreateRequest.

Implementations

Source

impl ProjectCreateRequestArgs

pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The friendly name of the project, this name appears in reports.

pub fn geography<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

Create the project with the specified data residency region. Your organization must have access to Data residency functionality in order to use. See data residency controls to review the functionality and limitations of setting this field.

pub fn external_key_id<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self

External key ID to associate with the project.

pub fn build(&self) -> Result<ProjectCreateRequest, OpenAIError>

Builds a new ProjectCreateRequest.

Errors

If a required field has not been initialized.