pub struct ProjectSpendAlert {
pub id: String,
pub object: String,
pub threshold_amount: i64,
pub currency: ProjectSpendAlertCurrency,
pub interval: ProjectSpendAlertInterval,
pub notification_channel: SpendAlertNotificationChannel,
}Available on crate feature
administration-types only.Expand description
Represents a spend alert configured at the project level.
Fields
id: StringThe identifier, which can be referenced in API endpoints.
object: StringThe object type, which is always project.spend_alert.
threshold_amount: i64The alert threshold amount, in cents.
currency: ProjectSpendAlertCurrencyThe currency for the threshold amount.
interval: ProjectSpendAlertIntervalThe time interval for evaluating spend against the threshold.
notification_channel: SpendAlertNotificationChannelTrait Implementations
Sourceimpl Clone for ProjectSpendAlert
impl Clone for ProjectSpendAlert
Sourcefn clone(&self) -> ProjectSpendAlert
fn clone(&self) -> ProjectSpendAlert
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProjectSpendAlert
impl Debug for ProjectSpendAlert
Sourceimpl<'de> Deserialize<'de> for ProjectSpendAlert
impl<'de> Deserialize<'de> for ProjectSpendAlert
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProjectSpendAlert
impl PartialEq for ProjectSpendAlert
Sourceimpl Serialize for ProjectSpendAlert
impl Serialize for ProjectSpendAlert
impl StructuralPartialEq for ProjectSpendAlert