pub struct ProjectSpendLimitResource {
pub object: String,
pub threshold_amount: i64,
pub currency: SpendLimitCurrency,
pub interval: SpendLimitInterval,
pub enforcement: SpendLimitEnforcement,
}Available on crate feature
administration-types only.Expand description
Represents a hard spend limit configured at the project level.
Fields
object: StringThe object type, which is always project.spend_limit.
threshold_amount: i64The hard spend limit amount, in cents.
currency: SpendLimitCurrencyThe currency for the threshold amount. Currently, only USD is supported.
interval: SpendLimitIntervalThe time interval for evaluating spend against the threshold. Currently, only month is supported.
enforcement: SpendLimitEnforcementThe current enforcement state of the hard spend limit.