pub struct UpdateProjectSpendLimitBody {
pub threshold_amount: i64,
pub currency: UpdateProjectSpendLimitBodyCurrency,
pub interval: UpdateProjectSpendLimitBodyInterval,
}Available on crate feature
administration-types only.Expand description
Parameters for the hard spend limit you want to create or replace.
Fields
threshold_amount: i64The hard spend limit amount, in cents.
currency: UpdateProjectSpendLimitBodyCurrencyThe currency for the threshold amount. Currently, only USD is supported.
interval: UpdateProjectSpendLimitBodyIntervalThe time interval for evaluating spend against the threshold. Currently, only month is supported.