pub struct CostsResult {
pub amount: CostsAmount,
pub line_item: Option<String>,
pub quantity: Option<f64>,
pub project_id: Option<String>,
pub api_key_id: Option<String>,
}Available on crate feature
administration-types only.Expand description
The aggregated costs details of the specific time bucket.
Fields
amount: CostsAmountThe monetary value in its associated currency.
line_item: Option<String>When group_by=line_item, this field provides the line item of the grouped costs result.
quantity: Option<f64>When group_by=line_item, this field provides the quantity of the grouped costs result.
project_id: Option<String>When group_by=project_id, this field provides the project ID of the grouped costs result.
api_key_id: Option<String>When group_by=api_key_id, this field provides the API Key ID of the grouped costs result.