pub struct UsageImagesResult {
pub images: u64,
pub num_model_requests: u64,
pub source: Option<String>,
pub size: Option<String>,
pub project_id: Option<String>,
pub user_id: Option<String>,
pub api_key_id: Option<String>,
pub model: Option<String>,
}Available on crate feature
administration-types only.Expand description
The aggregated images usage details of the specific time bucket.
Fields
images: u64The number of images processed.
num_model_requests: u64The count of requests made to the model.
source: Option<String>When group_by=source, this field provides the source of the grouped usage result, possible values are image.generation, image.edit, image.variation.
size: Option<String>When group_by=size, this field provides the image size of the grouped usage result.
project_id: Option<String>When group_by=project_id, this field provides the project ID of the grouped usage result.
user_id: Option<String>When group_by=user_id, this field provides the user ID of the grouped usage result.
api_key_id: Option<String>When group_by=api_key_id, this field provides the API key ID of the grouped usage result.
model: Option<String>When group_by=model, this field provides the model name of the grouped usage result.