pub struct AssistantObject {Show 13 fields
pub id: String,
pub object: String,
pub created_at: u64,
pub name: Option<String>,
pub description: Option<String>,
pub model: String,
pub instructions: Option<String>,
pub tools: Vec<AssistantTools>,
pub tool_resources: Option<AssistantToolResources>,
pub metadata: Option<HashMap<String, String>>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub response_format: Option<AssistantsApiResponseFormatOption>,
}Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
assistant-types only.Expand description
Represents an assistant that can call the model and use tools.
Fields
id: StringAssistants API is deprecated and will be removed in August 2026. Use the Responses API.
The identifier, which can be referenced in API endpoints.
object: StringAssistants API is deprecated and will be removed in August 2026. Use the Responses API.
The object type, which is always assistant.
created_at: u64Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
The Unix timestamp (in seconds) for when the assistant was created.
name: Option<String>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
The name of the assistant. The maximum length is 256 characters.
description: Option<String>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
The description of the assistant. The maximum length is 512 characters.
model: StringAssistants API is deprecated and will be removed in August 2026. Use the Responses API.
ID of the model to use. You can use the List models API to see all of your available models, or see our Model overview for descriptions of them.
instructions: Option<String>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
The system instructions that the assistant uses. The maximum length is 256,000 characters.
tools: Vec<AssistantTools>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
A list of tool enabled on the assistant. There can be a maximum of 128 tools per assistant. Tools can be of types code_interpreter, file_search, or function.
tool_resources: Option<AssistantToolResources>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
A set of resources that are used by the assistant’s tools. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.
metadata: Option<HashMap<String, String>>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format. Keys can be a maximum of 64 characters long and values can be a maximum of 512 characters long.
temperature: Option<f32>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
What sampling temperature to use, between 0 and 2. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.
top_p: Option<f32>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.
An alternative to sampling with temperature, called nucleus sampling, where the model considers the results of the tokens with top_p probability mass. So 0.1 means only the tokens comprising the top 10% probability mass are considered. We generally recommend altering this or temperature but not both.
response_format: Option<AssistantsApiResponseFormatOption>Assistants API is deprecated and will be removed in August 2026. Use the Responses API.