pub struct FunctionCall {
pub name: String,
pub arguments: String,
}Available on crate feature
assistant-types only.Expand description
The name and arguments of a function that should be called, as generated by the model.
Fields
name: StringThe name of the function to call.
arguments: StringThe arguments to call the function with, as generated by the model in JSON format. Note that the model does not always generate valid JSON, and may hallucinate parameters not defined by your function schema. Validate the arguments in your code before calling your function.