pub struct RunStepDeltaStepDetailsToolCallsCodeObject {
pub index: u32,
pub id: Option<String>,
pub code_interpreter: Option<DeltaCodeInterpreter>,
}Available on crate feature
assistant-types only.Expand description
Details of the Code Interpreter tool call the run step was involved in.
Fields
index: u32The index of the tool call in the tool calls array.
id: Option<String>The ID of the tool call.
code_interpreter: Option<DeltaCodeInterpreter>The Code Interpreter tool call definition.