pub struct CreateSpeechRequest {
pub input: String,
pub model: SpeechModel,
pub voice: Voice,
pub instructions: Option<String>,
pub response_format: Option<SpeechResponseFormat>,
pub speed: Option<f32>,
pub stream_format: Option<StreamFormat>,
}audio-types only.Fields
input: StringThe text to generate audio for. The maximum length is 4096 characters.
model: SpeechModelOne of the available TTS models: tts-1,
tts-1-hd or gpt-4o-mini-tts.
voice: VoiceThe voice to use when generating the audio. Supported built-in voices are alloy, ash,
ballad, coral, echo, fable, onyx, nova, sage, shimmer, verse, marin, and
cedar. Previews of the voices are available in the Text to speech
guide.
instructions: Option<String>Control the voice of your generated audio with additional instructions.
Does not work with tts-1 or tts-1-hd.
response_format: Option<SpeechResponseFormat>The format to audio in. Supported formats are mp3, opus, aac, flac, wav, and pcm.
speed: Option<f32>The speed of the generated audio. Select a value from 0.25 to 4.0. 1.0 is the default.
stream_format: Option<StreamFormat>The format to stream the audio in. Supported formats are sse and audio. sse is not
supported for tts-1 or tts-1-hd.