pub struct CreateImageEditRequest {Show 15 fields
pub image: ImageEditInput,
pub prompt: String,
pub mask: Option<ImageInput>,
pub background: Option<ImageBackground>,
pub model: Option<ImageModel>,
pub n: Option<u8>,
pub size: Option<ImageSize>,
pub response_format: Option<ImageResponseFormat>,
pub output_format: Option<ImageOutputFormat>,
pub output_compression: Option<u8>,
pub user: Option<String>,
pub input_fidelity: Option<InputFidelity>,
pub stream: Option<bool>,
pub partial_images: Option<u8>,
pub quality: Option<ImageQuality>,
}image-types only.Fields
image: ImageEditInputThe image(s) to edit. Must be a supported image file or an array of images.
For the GPT image models, each image should be a png, webp, or jpg
file less than 50MB. You can provide up to 16 images.
chatgpt-image-latest follows the same input constraints as GPT image models.
For dall-e-2, you can only provide one image, and it should be a square
png file less than 4MB.
prompt: StringA text description of the desired image(s). The maximum length is 1000 characters
for dall-e-2, and 32000 characters for the GPT image models.
mask: Option<ImageInput>An additional image whose fully transparent areas (e.g. where alpha is zero) indicate where
image should be edited. If there are multiple images provided, the mask will be applied on the
first image. Must be a valid PNG file, less than 4MB, and have the same dimensions as image.
background: Option<ImageBackground>Set the background of the generated image(s). This parameter is only
supported for the GPT image models. Must be one of transparent, opaque,
or auto (default value). When auto is used, the model will automatically
determine the best background for the image.
Transparent backgrounds are available for supported GPT Image models. For
gpt-image-2 and gpt-image-2-2026-04-21, this support is in preview. When
using transparent, set the output format to png or webp.
model: Option<ImageModel>The model to use for image generation. Supports dall-e-2, the GPT image
model family, and chatgpt-image-latest. Defaults to gpt-image-1.5.
n: Option<u8>The number of images to generate. Must be between 1 and 10.
size: Option<ImageSize>The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as
WIDTHxHEIGHT strings, for example 1536x864. Width and height
must both be divisible by 16 and the requested aspect ratio must be
between 1:3 and 3:1. Resolutions above 2560x1440 are experimental,
and the maximum supported resolution is 3840x2160. The requested
size must also satisfy the model’s current pixel and edge limits.
The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models
that allow automatic sizing. For dall-e-2, use one of 256x256,
512x512, or 1024x1024. For dall-e-3, use one of 1024x1024,
1792x1024, or 1024x1792.
response_format: Option<ImageResponseFormat>The format in which the generated images are returned. Must be one of url or b64_json. URLs
are only valid for 60 minutes after the image has been generated. This parameter is only supported
for dall-e-2, as the GPT image models will always return base64-encoded images.
output_format: Option<ImageOutputFormat>The format in which the generated images are returned. This parameter is
only supported for the GPT image models. Must be one of png, jpeg, or webp.
The default value is png.
output_compression: Option<u8>The compression level (0-100%) for the generated images. This parameter
is only supported for the GPT image models with the webp or jpeg output
formats, and defaults to 100.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
input_fidelity: Option<InputFidelity>Control how much effort the model will exert to match the style and features, especially facial
features, of input images. This parameter is only supported for the GPT image models. Unsupported for
gpt-image-1-mini. Supports high and low. Defaults to low.
stream: Option<bool>Edit the image in streaming mode. Defaults to false. See the
Image generation guide for more
information.
partial_images: Option<u8>The number of partial images to generate. This parameter is used for streaming responses that return partial images. Value must be between 0 and 3. When set to 0, the response will be a single image sent in one streaming event. Note that the final image may be sent before the full number of partial images are generated if the full image is generated more quickly.
quality: Option<ImageQuality>The quality of the image that will be generated. GPT image models support
quality levels through max; dall-e-2 supports standard. Defaults to auto.