pub struct CreateImageRequestArgs { /* private fields */ }image-types only.Expand description
Builder for CreateImageRequest.
Implementations
Sourceimpl CreateImageRequestArgs
impl CreateImageRequestArgs
Sourcepub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A text description of the desired image(s). The maximum length is 32000 characters for
the GPT image models, 1000 characters for dall-e-2 and 4000 characters for dall-e-3.
Sourcepub fn model<VALUE: Into<ImageModel>>(&mut self, value: VALUE) -> &mut Self
pub fn model<VALUE: Into<ImageModel>>(&mut self, value: VALUE) -> &mut Self
The model to use for image generation. One of dall-e-2, dall-e-3, or the GPT image model
(gpt-image-1, gpt-image-1-mini, gpt-image-1.5). Defaults
to dall-e-2 unless a parameter specific to the GPT image models is used.
Sourcepub fn n<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn n<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The number of images to generate. Must be between 1 and 10. For dall-e-3, only n=1 is supported.
Sourcepub fn quality<VALUE: Into<ImageQuality>>(&mut self, value: VALUE) -> &mut Self
pub fn quality<VALUE: Into<ImageQuality>>(&mut self, value: VALUE) -> &mut Self
The quality of the image that will be generated.
auto(default value) will automatically select the best quality for the given model.high,mediumandloware supported for the GPT image models.hdandstandardare supported fordall-e-3.standardis the only option fordall-e-2.
Sourcepub fn response_format<VALUE: Into<ImageResponseFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn response_format<VALUE: Into<ImageResponseFormat>>( &mut self, value: VALUE, ) -> &mut Self
The format in which generated images with dall-e-2 and dall-e-3 are returned. Must be one of
url or b64_json. URLs are only valid for 60 minutes after the image has been generated. This
parameter isn’t supported for the GPT image models which will always return base64-encoded images.
Sourcepub fn output_format<VALUE: Into<ImageOutputFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn output_format<VALUE: Into<ImageOutputFormat>>( &mut self, value: VALUE, ) -> &mut Self
The format in which the generated images are returned. This parameter is only supported for
the GPT image models. Must be one of png, jpeg, or webp.
Sourcepub fn output_compression<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn output_compression<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The compression level (0-100%) for the generated images. This parameter is only supported for
the GPT image models with the webp or jpeg output formats, and defaults to 100.
Sourcepub fn stream<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn stream<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Generate the image in streaming mode. Defaults to false. See the
Image generation guide for more
information. This parameter is only supported for the GPT image models.
Sourcepub fn partial_images<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn partial_images<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The number of partial images to generate. This parameter is used for streaming responses that return partial images. Value must be between 0 and 3. When set to 0, the response will be a single image sent in one streaming event. Note that the final image may be sent before the full number of partial images are generated if the full image is generated more quickly.
Sourcepub fn size<VALUE: Into<ImageSize>>(&mut self, value: VALUE) -> &mut Self
pub fn size<VALUE: Into<ImageSize>>(&mut self, value: VALUE) -> &mut Self
The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as
WIDTHxHEIGHT strings, for example 1536x864. Width and height
must both be divisible by 16 and the requested aspect ratio must be
between 1:3 and 3:1. Resolutions above 2560x1440 are experimental,
and the maximum supported resolution is 3840x2160. The requested
size must also satisfy the model’s current pixel and edge limits.
The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models
that allow automatic sizing. For dall-e-2, use one of 256x256,
512x512, or 1024x1024. For dall-e-3, use one of 1024x1024,
1792x1024, or 1024x1792.
Sourcepub fn moderation<VALUE: Into<ImageModeration>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn moderation<VALUE: Into<ImageModeration>>( &mut self, value: VALUE, ) -> &mut Self
Control the content-moderation level for images generated by the GPT image models. Must be either low
for less restrictive filtering or auto (default value).
Sourcepub fn background<VALUE: Into<ImageBackground>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn background<VALUE: Into<ImageBackground>>( &mut self, value: VALUE, ) -> &mut Self
Allows to set transparency for the background of the generated image(s).
This parameter is only supported for the GPT image models. Must be one of
transparent, opaque or auto (default value). When auto is used, the
model will automatically determine the best background for the image.
If transparent, the output format needs to support transparency, so it
should be set to either png (default value) or webp.
Sourcepub fn style<VALUE: Into<ImageStyle>>(&mut self, value: VALUE) -> &mut Self
pub fn style<VALUE: Into<ImageStyle>>(&mut self, value: VALUE) -> &mut Self
The style of the generated images. This parameter is only supported for dall-e-3. Must be one of
vivid or natural. Vivid causes the model to lean towards generating hyper-real and dramatic
images. Natural causes the model to produce more natural, less hyper-real looking images.
Sourcepub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse. Learn more.
Sourcepub fn build(&self) -> Result<CreateImageRequest, OpenAIError>
pub fn build(&self) -> Result<CreateImageRequest, OpenAIError>