pub struct EditImageJsonRequestArgs { /* private fields */ }image-types only.Expand description
Builder for EditImageJsonRequest.
Implementations
Sourceimpl EditImageJsonRequestArgs
impl EditImageJsonRequestArgs
Sourcepub fn model<VALUE: Into<ImageModel>>(&mut self, value: VALUE) -> &mut Self
pub fn model<VALUE: Into<ImageModel>>(&mut self, value: VALUE) -> &mut Self
The model to use for image editing.
Sourcepub fn images<VALUE: Into<Vec<ImageRefParam>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn images<VALUE: Into<Vec<ImageRefParam>>>( &mut self, value: VALUE, ) -> &mut Self
Input image references to edit. For GPT image models, you can provide up to 16 images.
Sourcepub fn mask<VALUE: Into<ImageRefParam>>(&mut self, value: VALUE) -> &mut Self
pub fn mask<VALUE: Into<ImageRefParam>>(&mut self, value: VALUE) -> &mut Self
An optional mask image reference indicating which areas of the image should be edited.
Sourcepub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn prompt<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A text description of the desired image edit.
Sourcepub fn n<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn n<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The number of edited images to generate. Must be between 1 and 10.
Sourcepub fn quality<VALUE: Into<ImageQuality>>(&mut self, value: VALUE) -> &mut Self
pub fn quality<VALUE: Into<ImageQuality>>(&mut self, value: VALUE) -> &mut Self
The quality of the image that will be generated.
Sourcepub fn input_fidelity<VALUE: Into<InputFidelity>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn input_fidelity<VALUE: Into<InputFidelity>>( &mut self, value: VALUE, ) -> &mut Self
Control how much effort the model will exert to match the style and features,
especially facial features, of input images. Supports high and low. Defaults to low.
Sourcepub fn size<VALUE: Into<ImageSize>>(&mut self, value: VALUE) -> &mut Self
pub fn size<VALUE: Into<ImageSize>>(&mut self, value: VALUE) -> &mut Self
The size of the generated image.
Sourcepub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn user<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A unique identifier representing your end-user.
Sourcepub fn output_format<VALUE: Into<ImageOutputFormat>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn output_format<VALUE: Into<ImageOutputFormat>>( &mut self, value: VALUE, ) -> &mut Self
The output format for the generated image.
Sourcepub fn output_compression<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn output_compression<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The compression level (0-100%) for the generated images.
Sourcepub fn moderation<VALUE: Into<ImageModeration>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn moderation<VALUE: Into<ImageModeration>>( &mut self, value: VALUE, ) -> &mut Self
Control the content-moderation level for images.
Sourcepub fn background<VALUE: Into<ImageBackground>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn background<VALUE: Into<ImageBackground>>( &mut self, value: VALUE, ) -> &mut Self
The background style for the generated image.
Sourcepub fn stream<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn stream<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to stream the image generation. Defaults to false.
Sourcepub fn partial_images<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
pub fn partial_images<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self
The number of partial images to generate during streaming.
Sourcepub fn build(&self) -> Result<EditImageJsonRequest, OpenAIError>
pub fn build(&self) -> Result<EditImageJsonRequest, OpenAIError>