pub struct RealtimeCreateClientSecretResponse {
pub value: String,
pub expires_at: u64,
pub session: Session,
}Available on crate feature
realtime-types only.Expand description
Response from creating a Realtime client secret.
Fields
value: StringThe generated client secret value.
expires_at: u64Expiration timestamp for the client secret, in seconds since epoch.
session: SessionThe session configuration for either a realtime or transcription session.