pub struct RealtimeTranslationSession {
pub id: String,
pub type: String,
pub expires_at: u64,
pub model: String,
pub audio: RealtimeTranslationAudio,
}Available on crate feature
realtime-types only.Expand description
A Realtime translation session. Translation sessions continuously translate input audio into the configured output language.
Fields
id: StringUnique identifier for the session that looks like sess_1234567890abcdef.
type: StringThe session type. Always translation for Realtime translation sessions.
expires_at: u64Expiration timestamp for the session, in seconds since epoch.
model: StringThe Realtime translation model used for this session.
audio: RealtimeTranslationAudioConfiguration for translation input and output audio.