pub enum ReasoningItemContent {
ReasoningText(ReasoningTextContent),
}Available on crate feature
response-types only.Expand description
ReasoningTextContent used elsewhere which adds type, but here in ReasoningItem content field we need type too hence an enum:
Variants
ReasoningText(ReasoningTextContent)