pub enum ServiceTierResponses {
Auto,
Default,
Flex,
Scale,
Priority,
Fast,
Ultrafast,
}Available on crate feature
response-types only.Expand description
Specifies the processing type used for serving the request.
- If set to ‘auto’, then the request will be processed with the service tier configured in the Project settings. Unless otherwise configured, the Project will use ‘default’.
- If set to ‘default’, then the request will be processed with the standard pricing and performance for the selected model.
- If set to ‘flex’, then the request will be processed with the Flex Processing service tier.
- To opt-in to Fast mode at the request level, include the
service_tier=fastorservice_tier=priorityparameter for Responses or Chat Completions. The response will showservice_tier=priorityregardless of if you specifyservice_tier=fastorpriorityin your request. - If set to ‘ultrafast’, then the request will be processed with the access-controlled Ultrafast
Processing service tier. This tier is currently available for
gpt-5.6-sol; a response served through it will showservice_tier=ultrafast. - When not set, the default behavior is ‘auto’.
When the service_tier parameter is set, the response body will include the service_tier value
based on the processing mode actually used to serve the request. This response value may be
different from the value set in the parameter.
Variants