pub struct ComputerToolCallOutputResource {
pub call_id: String,
pub output: ComputerScreenshotImage,
pub acknowledged_safety_checks: Option<Vec<ComputerCallSafetyCheckParam>>,
pub id: String,
pub status: ComputerCallOutputStatus,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A computer tool call output item returned by the API.
Fields
call_id: StringThe ID of the computer tool call that produced the output.
output: ComputerScreenshotImageA computer screenshot image used with the computer use tool.
acknowledged_safety_checks: Option<Vec<ComputerCallSafetyCheckParam>>The safety checks reported by the API that have been acknowledged by the developer.
id: StringThe unique ID of the computer tool call output.
status: ComputerCallOutputStatusThe status of the item returned by the API.
created_by: Option<String>The identifier of the actor that created the item.