pub struct ContainerFileCitationParam {
pub type: String,
pub start_index: u64,
pub end_index: u64,
pub container_id: String,
pub file_id: String,
pub filename: String,
}Available on crate feature
response-types only.Fields
type: StringThe citation type. Always container_file_citation.
start_index: u64The index of the first character of the citation in the message.
end_index: u64The index of the last character of the citation in the message.
container_id: StringThe ID of the container.
file_id: StringThe ID of the container file.
filename: StringThe filename of the container file cited.