#[non_exhaustive]pub struct CustomToolCallResource {
pub call_id: String,
pub namespace: Option<String>,
pub input: String,
pub name: String,
pub id: String,
pub status: FunctionCallStatus,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A custom tool call item returned by the API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.call_id: StringAn identifier used to map this custom tool call to a tool call output.
namespace: Option<String>The namespace of the custom tool being called.
input: StringThe input for the custom tool call generated by the model.
name: StringThe name of the custom tool being called.
id: StringThe unique ID of the custom tool call in the OpenAI platform.
status: FunctionCallStatusThe status of the item. One of in_progress, completed, or incomplete.
created_by: Option<String>The identifier of the actor that created the item.