pub struct FunctionToolCallOutputResource {
pub call_id: String,
pub output: FunctionCallOutput,
pub id: String,
pub status: FunctionCallOutputStatusEnum,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A function tool call output item returned by the API.
Fields
call_id: StringThe unique ID of the function tool call generated by the model.
output: FunctionCallOutputText, image, or file output of the function tool call.
id: StringThe unique ID of the function tool call output.
status: FunctionCallOutputStatusEnumThe status of the item. One of in_progress, completed, or incomplete.
created_by: Option<String>The identifier of the actor that created the item.