pub struct FunctionToolCallResource {
pub arguments: String,
pub call_id: String,
pub namespace: Option<String>,
pub name: String,
pub id: String,
pub status: FunctionCallStatus,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A function tool call item returned by the API.
Fields
arguments: StringA JSON string of the arguments to pass to the function.
call_id: StringThe unique ID of the function tool call generated by the model.
namespace: Option<String>The namespace of the function to run.
name: StringThe name of the function to run.
id: StringThe unique ID of the function tool call.
status: FunctionCallStatusThe status of the item. One of in_progress, completed, or incomplete.
created_by: Option<String>The identifier of the actor that created the item.