pub struct FunctionToolParam {
pub name: String,
pub description: Option<String>,
pub parameters: Option<Value>,
pub strict: Option<bool>,
pub defer_loading: Option<bool>,
}Available on crate feature
response-types only.Expand description
A function tool that can be used within a namespace or with tool search.
Fields
name: StringThe name of the function.
description: Option<String>A description of the function.
parameters: Option<Value>A JSON schema object describing the parameters of the function.
strict: Option<bool>Whether to enforce strict parameter validation.
defer_loading: Option<bool>Whether this function should be deferred and discovered via tool search.