pub struct FunctionToolParamArgs { /* private fields */ }Available on crate feature
response-types only.Expand description
Builder for FunctionToolParam.
Implementations
Sourceimpl FunctionToolParamArgs
impl FunctionToolParamArgs
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The name of the function.
Sourcepub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A description of the function.
Sourcepub fn parameters<VALUE: Into<Value>>(&mut self, value: VALUE) -> &mut Self
pub fn parameters<VALUE: Into<Value>>(&mut self, value: VALUE) -> &mut Self
A JSON schema object describing the parameters of the function.
Sourcepub fn strict<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn strict<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether to enforce strict parameter validation.
Sourcepub fn defer_loading<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn defer_loading<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Whether this function should be deferred and discovered via tool search.
Sourcepub fn build(&self) -> Result<FunctionToolParam, OpenAIError>
pub fn build(&self) -> Result<FunctionToolParam, OpenAIError>