ImageGenerationArgs

Struct ImageGenerationArgs 

pub struct ImageGenerationArgs { /* private fields */ }
Available on crate feature response-types only.
Builder for ImageGenTool.

Implementations

Source

impl ImageGenerationArgs

pub fn background<VALUE: Into<ImageGenToolBackground>>( &mut self, value: VALUE, ) -> &mut Self

Background type for the generated image. One of transparent, opaque, or auto. Default: auto.

pub fn input_fidelity<VALUE: Into<InputFidelity>>( &mut self, value: VALUE, ) -> &mut Self

Control how much effort the model will exert to match the style and features, especially facial features, of input images. This parameter is only supported for gpt-image-1. Unsupported for gpt-image-1-mini. Supports high and low. Defaults to low.

pub fn input_image_mask<VALUE: Into<ImageGenToolInputImageMask>>( &mut self, value: VALUE, ) -> &mut Self

Optional mask for inpainting. Contains image_url (string, optional) and file_id (string, optional).

pub fn model<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The image generation model to use. Default: gpt-image-1.

pub fn moderation<VALUE: Into<ImageGenToolModeration>>( &mut self, value: VALUE, ) -> &mut Self

Moderation level for the generated image. Default: auto.

pub fn output_compression<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self

Compression level for the output image. Default: 100.

pub fn output_format<VALUE: Into<ImageGenToolOutputFormat>>( &mut self, value: VALUE, ) -> &mut Self

The output format of the generated image. One of png, webp, or jpeg. Default: png.

pub fn partial_images<VALUE: Into<u8>>(&mut self, value: VALUE) -> &mut Self

Number of partial images to generate in streaming mode, from 0 (default value) to 3.

pub fn quality<VALUE: Into<ImageGenToolQuality>>( &mut self, value: VALUE, ) -> &mut Self

The quality of the generated image. One of low, medium, high, or auto. Default: auto.

pub fn size<VALUE: Into<ImageGenToolSize>>(&mut self, value: VALUE) -> &mut Self

The size of the generated images. For gpt-image-2 and gpt-image-2-2026-04-21, arbitrary resolutions are supported as WIDTHxHEIGHT strings, for example 1536x864. Width and height must both be divisible by 16 and the requested aspect ratio must be between 1:3 and 3:1. Resolutions above 2560x1440 are experimental, and the maximum supported resolution is 3840x2160. The requested size must also satisfy the model’s current pixel and edge limits. The standard sizes 1024x1024, 1536x1024, and 1024x1536 are supported by the GPT image models; auto is supported for models that allow automatic sizing. For dall-e-2, use one of 256x256, 512x512, or 1024x1024. For dall-e-3, use one of 1024x1024, 1792x1024, or 1024x1792.

pub fn action<VALUE: Into<ImageGenActionEnum>>( &mut self, value: VALUE, ) -> &mut Self

Whether to generate a new image or edit an existing image. Default: auto.

pub fn build(&self) -> Result<ImageGenTool, OpenAIError>

Builds a new ImageGenTool.

Errors

If a required field has not been initialized.