InputFileArgs

Struct InputFileArgs 

pub struct InputFileArgs { /* private fields */ }
Available on crate feature response-types only.
Builder for InputFileContent.

Implementations

Source

impl InputFileArgs

pub fn file_data<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The content of the file to be sent to the model.

pub fn file_id<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The ID of the file to be sent to the model.

pub fn file_url<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The URL of the file to be sent to the model.

pub fn filename<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

The name of the file to be sent to the model.

pub fn detail<VALUE: Into<FileInputDetail>>( &mut self, value: VALUE, ) -> &mut Self

The detail level of the file to be sent to the model. Use low for the default rendering behavior, or high to render the file at higher quality. Defaults to low.

pub fn build(&self) -> Result<InputFileContent, OpenAIError>

Builds a new InputFileContent.

Errors

If a required field has not been initialized.