pub struct InputFileContent {
pub file_data: Option<String>,
pub file_id: Option<String>,
pub file_url: Option<String>,
pub filename: Option<String>,
pub detail: Option<FileInputDetail>,
}Available on crate feature
response-types only.Fields
file_data: Option<String>The content of the file to be sent to the model.
file_id: Option<String>The ID of the file to be sent to the model.
file_url: Option<String>The URL of the file to be sent to the model.
filename: Option<String>The name of the file to be sent to the model.
detail: Option<FileInputDetail>The detail level of the file to be sent to the model. Use low for the default rendering
behavior, or high to render the file at higher quality. Defaults to low.