pub struct PromptCacheMissDiagnosticsBody {
pub reason: CacheMissReasonTypeEnum,
pub cache_missed_tokens: u64,
pub comparison_reusable_tokens: Option<u64>,
}Available on crate feature
response-types only.Fields
reason: CacheMissReasonTypeEnumThe reason prompt cache reuse did not occur.
cache_missed_tokens: u64The estimated number of input tokens affected after the first detected divergence.
comparison_reusable_tokens: Option<u64>The raw token count of the reusable prefix in the compared response.