pub struct ResponseShellCallCommandDeltaStreamingEvent {
pub sequence_number: u64,
pub output_index: u32,
pub command_index: u32,
pub delta: String,
pub obfuscation: Option<String>,
}Available on crate feature
response-types only.Expand description
A streaming event that indicated a shell command was incrementally updated.
Fields
sequence_number: u64The sequence number of the event that was emitted.
output_index: u32The index of the output item that was updated.
command_index: u32The index of the shell command that was updated.
delta: StringThe shell command delta that was appended.
obfuscation: Option<String>An obfuscation string that was added to pad the event payload.