pub struct ResponseShellCallCommandDoneStreamingEvent {
pub sequence_number: u64,
pub output_index: u32,
pub command_index: u32,
pub command: String,
}Available on crate feature
response-types only.Expand description
A streaming event that indicated a shell command was completed.
Fields
sequence_number: u64The sequence number of the event that was emitted.
output_index: u32The index of the output item that was updated.
command_index: u32The index of the shell command that was completed.
command: StringThe final shell command that was emitted.