pub struct ResponseShellCallOutputContentDoneStreamingEvent {
pub sequence_number: u64,
pub item_id: String,
pub output_index: u32,
pub command_index: u32,
pub output: Vec<FunctionShellCallOutputContent>,
}Available on crate feature
response-types only.Expand description
A streaming event that indicated shell call output was completed.
Fields
sequence_number: u64The sequence number of the event that was emitted.
item_id: StringThe ID of the output item that was updated.
output_index: u32The index of the output item that was updated.
command_index: u32The index of the shell command that produced output.
output: Vec<FunctionShellCallOutputContent>The output contents emitted for the shell command.