pub struct ToolSearchCall {
pub id: String,
pub call_id: Option<String>,
pub execution: ToolSearchExecutionType,
pub arguments: Value,
pub status: FunctionCallStatus,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A tool search call output item.
Fields
id: StringThe unique ID of the tool search call item.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: ToolSearchExecutionTypeWhether tool search was executed by the server or by the client.
arguments: ValueArguments used for the tool search call.
status: FunctionCallStatusThe status of the tool search call item.
created_by: Option<String>The identifier of the actor that created the item.