pub struct ToolSearchCallItemParam {
pub id: Option<String>,
pub call_id: Option<String>,
pub execution: Option<ToolSearchExecutionType>,
pub arguments: Value,
pub status: Option<OutputStatus>,
}Available on crate feature
response-types only.Expand description
A tool search call input item.
Fields
id: Option<String>The unique ID of this tool search call.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: Option<ToolSearchExecutionType>Whether tool search was executed by the server or by the client.
arguments: ValueThe arguments supplied to the tool search call.
status: Option<OutputStatus>The status of the tool search call.