pub struct ToolSearchOutput {
pub id: String,
pub call_id: Option<String>,
pub execution: ToolSearchExecutionType,
pub tools: Vec<Tool>,
pub status: FunctionCallOutputStatusEnum,
pub created_by: Option<String>,
}Available on crate feature
response-types only.Expand description
A tool search output item.
Fields
id: StringThe unique ID of the tool search output item.
call_id: Option<String>The unique ID of the tool search call generated by the model.
execution: ToolSearchExecutionTypeWhether tool search was executed by the server or by the client.
tools: Vec<Tool>The loaded tool definitions returned by tool search.
status: FunctionCallOutputStatusEnumThe status of the tool search output item.
created_by: Option<String>The identifier of the actor that created the item.