pub struct UrlCitationParam {
pub type: String,
pub start_index: u64,
pub end_index: u64,
pub url: String,
pub title: String,
}Available on crate feature
response-types only.Fields
type: StringThe citation type. Always url_citation.
start_index: u64The index of the first character of the citation in the message.
end_index: u64The index of the last character of the citation in the message.
url: StringThe URL of the cited resource.
title: StringThe title of the cited resource.