ResponsesServerEvent

Enum ResponsesServerEvent 

pub enum ResponsesServerEvent {
Show 61 variants ResponseAudioDelta(ResponseAudioWsDelta), ResponseAudioDone(ResponseAudioWsDone), ResponseAudioTranscriptDelta(ResponseAudioTranscriptWsDelta), ResponseAudioTranscriptDone(ResponseAudioTranscriptWsDone), ResponseCodeInterpreterCallCodeDelta(ResponseCodeInterpreterCallCodeWsDelta), ResponseCodeInterpreterCallCodeDone(ResponseCodeInterpreterCallCodeWsDone), ResponseCodeInterpreterCallCompleted(ResponseCodeInterpreterCallWsCompleted), ResponseCodeInterpreterCallInProgress(ResponseCodeInterpreterCallInWsProgress), ResponseCodeInterpreterCallInterpreting(ResponseCodeInterpreterCallWsInterpreting), ResponseCompleted(ResponseWsCompleted), ResponseContentPartAdded(ResponseContentPartWsAdded), ResponseContentPartDone(ResponseContentPartWsDone), ResponseCreated(ResponseWsCreated), ResponseFileSearchCallCompleted(ResponseFileSearchCallWsCompleted), ResponseFileSearchCallInProgress(ResponseFileSearchCallInWsProgress), ResponseFileSearchCallSearching(ResponseFileSearchCallWsSearching), ResponseFunctionCallArgumentsDelta(ResponseFunctionCallArgumentsWsDelta), ResponseFunctionCallArgumentsDone(ResponseFunctionCallArgumentsWsDone), ResponseShellCallCommandAdded(ResponseShellCallCommandWsAdded), ResponseShellCallCommandDelta(ResponseShellCallCommandWsDelta), ResponseShellCallCommandDone(ResponseShellCallCommandWsDone), ResponseShellCallOutputContentDelta(ResponseShellCallOutputContentWsDelta), ResponseShellCallOutputContentDone(ResponseShellCallOutputContentWsDone), ResponseInProgress(ResponseInWsProgress), ResponseFailed(ResponseWsFailed), ResponseIncomplete(ResponseWsIncomplete), ResponseOutputItemAdded(ResponseOutputItemWsAdded), ResponseOutputItemDone(ResponseOutputItemWsDone), ResponseReasoningSummaryPartAdded(ResponseReasoningSummaryPartWsAdded), ResponseReasoningSummaryPartDone(ResponseReasoningSummaryPartWsDone), ResponseReasoningSummaryTextDelta(ResponseReasoningSummaryTextWsDelta), ResponseReasoningSummaryTextDone(ResponseReasoningSummaryTextWsDone), ResponseReasoningTextDelta(ResponseReasoningTextWsDelta), ResponseReasoningTextDone(ResponseReasoningTextWsDone), ResponseRefusalDelta(ResponseRefusalWsDelta), ResponseRefusalDone(ResponseRefusalWsDone), ResponseOutputTextDelta(ResponseTextWsDelta), ResponseOutputTextDone(ResponseTextWsDone), ResponseWebSearchCallCompleted(ResponseWebSearchCallWsCompleted), ResponseWebSearchCallInProgress(ResponseWebSearchCallInWsProgress), ResponseWebSearchCallSearching(ResponseWebSearchCallWsSearching), ResponseImageGenerationCallCompleted(ResponseImageGenCallWsCompleted), ResponseImageGenerationCallGenerating(ResponseImageGenCallWsGenerating), ResponseImageGenerationCallInProgress(ResponseImageGenCallInWsProgress), ResponseImageGenerationCallPartialImage(ResponseImageGenCallPartialWsImage), ResponseMCPCallArgumentsDelta(ResponseMcpCallArgumentsWsDelta), ResponseMCPCallArgumentsDone(ResponseMcpCallArgumentsWsDone), ResponseMCPCallCompleted(ResponseMcpCallWsCompleted), ResponseMCPCallFailed(ResponseMcpCallWsFailed), ResponseMCPCallInProgress(ResponseMcpCallInWsProgress), ResponseMCPListToolsCompleted(ResponseMcpListToolsWsCompleted), ResponseMCPListToolsFailed(ResponseMcpListToolsWsFailed), ResponseMCPListToolsInProgress(ResponseMcpListToolsInWsProgress), ResponseOutputTextAnnotationAdded(ResponseOutputTextAnnotationWsAdded), ResponseQueued(ResponseWsQueued), ResponseCustomToolCallInputDelta(ResponseCustomToolCallInputWsDelta), ResponseCustomToolCallInputDone(ResponseCustomToolCallInputWsDone), Error(ResponseWsError), SteerAccepted(ResponseSteerAcceptedEvent), SteerPending(ResponseSteerPendingEvent), SteerFailed(ResponseSteerFailedEvent),
}
Available on crate feature response-types only.
Server events received on a Responses WebSocket connection.

Variants



ResponseAudioDelta(ResponseAudioWsDelta)

Emitted when there is a partial audio response.



ResponseAudioDone(ResponseAudioWsDone)

Emitted when the audio response is complete.



ResponseAudioTranscriptDelta(ResponseAudioTranscriptWsDelta)

Emitted when there is a partial transcript of audio.



ResponseAudioTranscriptDone(ResponseAudioTranscriptWsDone)

Emitted when the full audio transcript is completed.



ResponseCodeInterpreterCallCodeDelta(ResponseCodeInterpreterCallCodeWsDelta)

Emitted when a partial code snippet is streamed by the code interpreter.



ResponseCodeInterpreterCallCodeDone(ResponseCodeInterpreterCallCodeWsDone)

Emitted when the code snippet is finalized by the code interpreter.



ResponseCodeInterpreterCallCompleted(ResponseCodeInterpreterCallWsCompleted)

Emitted when the code interpreter call is completed.



ResponseCodeInterpreterCallInProgress(ResponseCodeInterpreterCallInWsProgress)

Emitted when a code interpreter call is in progress.



ResponseCodeInterpreterCallInterpreting(ResponseCodeInterpreterCallWsInterpreting)

Emitted when the code interpreter is actively interpreting the code snippet.



ResponseCompleted(ResponseWsCompleted)

Emitted when the model response is complete.



ResponseContentPartAdded(ResponseContentPartWsAdded)

Emitted when a new content part is added.



ResponseContentPartDone(ResponseContentPartWsDone)

Emitted when a content part is done.



ResponseCreated(ResponseWsCreated)

An event that is emitted when a response is created.



ResponseFileSearchCallCompleted(ResponseFileSearchCallWsCompleted)

Emitted when a file search call is completed (results found).



ResponseFileSearchCallInProgress(ResponseFileSearchCallInWsProgress)

Emitted when a file search call is initiated.



ResponseFileSearchCallSearching(ResponseFileSearchCallWsSearching)

Emitted when a file search is currently searching.



ResponseFunctionCallArgumentsDelta(ResponseFunctionCallArgumentsWsDelta)

Emitted when there is a partial function-call arguments delta.



ResponseFunctionCallArgumentsDone(ResponseFunctionCallArgumentsWsDone)

Emitted when function-call arguments are finalized.



ResponseShellCallCommandAdded(ResponseShellCallCommandWsAdded)

A streaming event that indicated a shell command was added to a tool call.



ResponseShellCallCommandDelta(ResponseShellCallCommandWsDelta)

A streaming event that indicated a shell command was incrementally updated.



ResponseShellCallCommandDone(ResponseShellCallCommandWsDone)

A streaming event that indicated a shell command was completed.



ResponseShellCallOutputContentDelta(ResponseShellCallOutputContentWsDelta)

A streaming event that indicated shell call output was incrementally added.



ResponseShellCallOutputContentDone(ResponseShellCallOutputContentWsDone)

A streaming event that indicated shell call output was completed.



ResponseInProgress(ResponseInWsProgress)

Emitted when the response is in progress.



ResponseFailed(ResponseWsFailed)

An event that is emitted when a response fails.



ResponseIncomplete(ResponseWsIncomplete)

An event that is emitted when a response finishes as incomplete.

Over WebSocket, steering can finish a response with response.incomplete_details.reason set to steered, followed automatically by a successor response.created that commits the queued steering input.



ResponseOutputItemAdded(ResponseOutputItemWsAdded)

Emitted when a new output item is added.



ResponseOutputItemDone(ResponseOutputItemWsDone)

Emitted when an output item is marked done.



ResponseReasoningSummaryPartAdded(ResponseReasoningSummaryPartWsAdded)

Emitted when a new reasoning summary part is added.



ResponseReasoningSummaryPartDone(ResponseReasoningSummaryPartWsDone)

Emitted when a reasoning summary part is completed.



ResponseReasoningSummaryTextDelta(ResponseReasoningSummaryTextWsDelta)

Emitted when a delta is added to a reasoning summary text.



ResponseReasoningSummaryTextDone(ResponseReasoningSummaryTextWsDone)

Emitted when a reasoning summary text is completed.



ResponseReasoningTextDelta(ResponseReasoningTextWsDelta)

Emitted when a delta is added to a reasoning text.



ResponseReasoningTextDone(ResponseReasoningTextWsDone)

Emitted when a reasoning text is completed.



ResponseRefusalDelta(ResponseRefusalWsDelta)

Emitted when there is a partial refusal text.



ResponseRefusalDone(ResponseRefusalWsDone)

Emitted when refusal text is finalized.



ResponseOutputTextDelta(ResponseTextWsDelta)

Emitted when there is an additional text delta.



ResponseOutputTextDone(ResponseTextWsDone)

Emitted when text content is finalized.



ResponseWebSearchCallCompleted(ResponseWebSearchCallWsCompleted)

Emitted when a web search call is completed.



ResponseWebSearchCallInProgress(ResponseWebSearchCallInWsProgress)

Emitted when a web search call is initiated.



ResponseWebSearchCallSearching(ResponseWebSearchCallWsSearching)

Emitted when a web search call is executing.



ResponseImageGenerationCallCompleted(ResponseImageGenCallWsCompleted)

Emitted when an image generation tool call has completed and the final image is available.



ResponseImageGenerationCallGenerating(ResponseImageGenCallWsGenerating)

Emitted when an image generation tool call is actively generating an image (intermediate state).



ResponseImageGenerationCallInProgress(ResponseImageGenCallInWsProgress)

Emitted when an image generation tool call is in progress.



ResponseImageGenerationCallPartialImage(ResponseImageGenCallPartialWsImage)

Emitted when a partial image is available during image generation streaming.



ResponseMCPCallArgumentsDelta(ResponseMcpCallArgumentsWsDelta)

Emitted when there is a delta (partial update) to the arguments of an MCP tool call.



ResponseMCPCallArgumentsDone(ResponseMcpCallArgumentsWsDone)

Emitted when the arguments for an MCP tool call are finalized.



ResponseMCPCallCompleted(ResponseMcpCallWsCompleted)

Emitted when an MCP tool call has completed successfully.



ResponseMCPCallFailed(ResponseMcpCallWsFailed)

Emitted when an MCP tool call has failed.



ResponseMCPCallInProgress(ResponseMcpCallInWsProgress)

Emitted when an MCP tool call is in progress.



ResponseMCPListToolsCompleted(ResponseMcpListToolsWsCompleted)

Emitted when the list of available MCP tools has been successfully retrieved.



ResponseMCPListToolsFailed(ResponseMcpListToolsWsFailed)

Emitted when the attempt to list available MCP tools has failed.



ResponseMCPListToolsInProgress(ResponseMcpListToolsInWsProgress)

Emitted when the system is in the process of retrieving the list of available MCP tools.



ResponseOutputTextAnnotationAdded(ResponseOutputTextAnnotationWsAdded)

Emitted when an annotation is added to output text content.



ResponseQueued(ResponseWsQueued)

Emitted when a response is queued and waiting to be processed.



ResponseCustomToolCallInputDelta(ResponseCustomToolCallInputWsDelta)

Event representing a delta (partial update) to the input of a custom tool call.



ResponseCustomToolCallInputDone(ResponseCustomToolCallInputWsDone)

Event indicating that input for a custom tool call is complete.



Error(ResponseWsError)



SteerAccepted(ResponseSteerAcceptedEvent)



SteerPending(ResponseSteerPendingEvent)



SteerFailed(ResponseSteerFailedEvent)