pub enum VideoEditInput {
Reference(VideoReferenceInputParam),
Input(InputSource),
}Available on crate feature
video-types only.Expand description
Input for video edit - either a reference to an existing video or a file upload.
Variants
Reference(VideoReferenceInputParam)
A reference to a completed video by its ID.
Input(InputSource)
A video input source.