pub struct WebhookSafetyAlertCreated {
pub id: String,
pub object: String,
pub created_at: u64,
pub data: WebhookSafetyAlertCreatedData,
}Available on crate feature
webhook-types only.Expand description
Sent when an approved safety alert is available for an API project.
Fields
id: StringThe unique ID of the webhook event.
object: StringAlways event.
created_at: u64The Unix timestamp in seconds when the event was created.
data: WebhookSafetyAlertCreatedDataTrait Implementations
Sourceimpl Clone for WebhookSafetyAlertCreated
impl Clone for WebhookSafetyAlertCreated
Sourcefn clone(&self) -> WebhookSafetyAlertCreated
fn clone(&self) -> WebhookSafetyAlertCreated
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebhookSafetyAlertCreated
impl Debug for WebhookSafetyAlertCreated
Sourceimpl<'de> Deserialize<'de> for WebhookSafetyAlertCreated
impl<'de> Deserialize<'de> for WebhookSafetyAlertCreated
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EventId for WebhookSafetyAlertCreated
impl EventId for WebhookSafetyAlertCreated
Sourceimpl EventType for WebhookSafetyAlertCreated
impl EventType for WebhookSafetyAlertCreated
Sourcefn event_type(&self) -> &'static str
fn event_type(&self) -> &'static str
Available on crate feature
_api only.Returns the event type string (e.g., “batch.cancelled”)
impl StructuralPartialEq for WebhookSafetyAlertCreated