Module types

Module types 

Types used in OpenAI API requests and responses. These types are created from component schemas in the OpenAPI spec

Modules

adminadministration-types
Admin-related types for organization management APIs.
assistantsassistant-types
audioaudio-types
batchesbatch-types
chatchat-completion-types
chatkitchatkit-types
completionscompletion-types
containerscontainer-types
embeddingsembedding-types
evalseval-types
filesfile-types
finetuningfinetuning-types
gradersgrader-types
imagesimage-types
mcpresponse-types or realtime-types
modelsmodel-types
moderationsmoderation-types
realtimerealtime-types
responsesresponse-types
skillsskill-types
stream_api
uploadsupload-types
vectorstoresvectorstore-types
videosvideo-types
webhookswebhook-types

Structs

Metadataresponse-types or audio-types or video-types or image-types or batch-types or file-types or upload-types or vectorstore-types or container-types or chat-completion-types or realtime-types
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

Enums

InputSourceaudio-types or file-types or upload-types or image-types or video-types or container-types or skill-types or chat-completion-types or realtime-types