pub struct ProjectCreateRequestArgs { /* private fields */ }Available on crate feature
administration-types only.Expand description
Builder for ProjectCreateRequest.
Implementations
Sourceimpl ProjectCreateRequestArgs
impl ProjectCreateRequestArgs
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The friendly name of the project, this name appears in reports.
Sourcepub fn geography<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn geography<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
Create the project with the specified data residency region. Your organization must have access to Data residency functionality in order to use. See data residency controls to review the functionality and limitations of setting this field.
Sourcepub fn external_key_id<VALUE: Into<String>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn external_key_id<VALUE: Into<String>>( &mut self, value: VALUE, ) -> &mut Self
External key ID to associate with the project.
Sourcepub fn build(&self) -> Result<ProjectCreateRequest, OpenAIError>
pub fn build(&self) -> Result<ProjectCreateRequest, OpenAIError>