pub struct ImageGenTool {
pub background: Option<ImageGenToolBackground>,
pub input_fidelity: Option<InputFidelity>,
pub input_image_mask: Option<ImageGenToolInputImageMask>,
pub model: Option<String>,
pub moderation: Option<ImageGenToolModeration>,
pub output_compression: Option<u8>,
pub output_format: Option<ImageGenToolOutputFormat>,
pub partial_images: Option<u8>,
pub quality: Option<ImageGenToolQuality>,
pub size: Option<ImageGenToolSize>,
pub action: Option<ImageGenActionEnum>,
}response-types only.Expand description
Image generation tool definition.
Fields
background: Option<ImageGenToolBackground>Background type for the generated image. One of transparent,
opaque, or auto. Default: auto.
input_fidelity: Option<InputFidelity>Control how much effort the model will exert to match the style and features, especially facial features,
of input images. This parameter is only supported for gpt-image-1. Unsupported
for gpt-image-1-mini. Supports high and low. Defaults to low.
input_image_mask: Option<ImageGenToolInputImageMask>Optional mask for inpainting. Contains image_url
(string, optional) and file_id (string, optional).
model: Option<String>The image generation model to use. Default: gpt-image-1.
moderation: Option<ImageGenToolModeration>Moderation level for the generated image. Default: auto.
output_compression: Option<u8>Compression level for the output image. Default: 100.
output_format: Option<ImageGenToolOutputFormat>The output format of the generated image. One of png, webp, or
jpeg. Default: png.
partial_images: Option<u8>Number of partial images to generate in streaming mode, from 0 (default value) to 3.
quality: Option<ImageGenToolQuality>The quality of the generated image. One of low, medium, high,
or auto. Default: auto.
size: Option<ImageGenToolSize>The size of the generated images. For gpt-image-2 and
gpt-image-2-2026-04-21, arbitrary resolutions are supported as
WIDTHxHEIGHT strings, for example 1536x864. Width and height
must both be divisible by 16 and the requested aspect ratio must be
between 1:3 and 3:1. Resolutions above 2560x1440 are experimental,
and the maximum supported resolution is 3840x2160. The requested
size must also satisfy the model’s current pixel and edge limits.
The standard sizes 1024x1024, 1536x1024, and 1024x1536 are
supported by the GPT image models; auto is supported for models
that allow automatic sizing. For dall-e-2, use one of 256x256,
512x512, or 1024x1024. For dall-e-3, use one of 1024x1024,
1792x1024, or 1024x1792.
action: Option<ImageGenActionEnum>Whether to generate a new image or edit an existing image. Default: auto.